@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2001, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/box.c,v 4.14 2001/08/06 21:38:55 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/box.c,v 4.16 2002/03/06 07:23:39 william Exp $
  */
 
 #define _INCLUDE_FROM_BOX_C_
@@ -454,7 +454,7 @@ void ContinueBox(OrigX, OrigY)
             sprintf(buf, "w=%s\nh=%s\nx=%s\ny=%s", w_buf, h_buf, x_buf, y_buf);
             ShowMeasureCursor(saved_x, saved_y, buf, TRUE);
          }
-         DrawIntervalRulers(OrigX, OrigY, grid_x, grid_y);
+         DrawIntervalRulers(OrigX, OrigY, grid_x, grid_y, NULL);
          while (XCheckMaskEvent(mainDisplay, PointerMotionMask, &ev)) ;
       } else if (input.type == KeyPress) {
          if (KeyPressEventIsEscape(&input.xkey)) {
