@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2001, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/grid.c,v 4.43 2001/08/06 21:39:04 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/grid.c,v 4.45 2002/03/21 07:44:50 william Exp $
  */
 
 #define _INCLUDE_FROM_GRID_C_
@@ -1366,6 +1366,8 @@ int RefreshShowHideMenu(menu)
    /* ShowChoice */
    ok &= TgSetMenuItemCheckById(menu, CMDID_TOGGLESHOWCHOICEBAR,
          !noChoiceWindow);
+   /* ShowMode */
+   ok &= TgSetMenuItemCheckById(menu, CMDID_TOGGLESHOWMODE, !noModeWindow);
 
    return ok;
 }
