@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2001, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/ruler.c,v 4.18 2001/08/06 21:39:12 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/ruler.c,v 4.22 2002/03/08 01:01:34 william Exp $
  */
 
 #define _INCLUDE_FROM_RULER_C_
@@ -31,6 +31,7 @@
 #include "msg.e"
 #include "raster.e"
 #include "ruler.e"
+#include "select.e"
 #include "setup.e"
 #include "strtbl.e"
 #include "util.e"
@@ -47,6 +48,7 @@
 
 int showMeasurement=FALSE;
 int showMeasurementInTooltip=TRUE;
+int simpleMotionInDrawWin=FALSE;
 int showCrossHair=FALSE;
 
 static int measureTooltipVerbose=FALSE;
@@ -63,6 +65,9 @@ static int oldXOff=(-1), oldYOff=(-1);
 static int rulerLen=0;
 static int hRulerJustRedrawn=TRUE, justUnFrozen=FALSE;
 static int freezeMarkRulerText=FALSE, frozenXOff=0, frozenYOff=0;
+static char *gpszFrozenDeltaStr=NULL;
+
+static char *gpszOldDeltaStr=NULL;
 
 void GetUnitSpec(buf)
    char *buf;
@@ -479,7 +484,7 @@ void RedrawVRulerWindow()
 void MarkRulers(XOff, YOff)
    int XOff, YOff;
 {
-   char x_buf[80], y_buf[80], buf[80];
+   char x_buf[80], y_buf[80], buf[MAXSTRING];
 
    DrawHRuleTick(oldXOff-1);
    DrawVRuleTick(oldYOff-1);
@@ -519,22 +524,37 @@ void MarkRulers(XOff, YOff)
    if (!freezeMarkRulerText && showMeasurement) {
       PixelToMeasurementUnit(x_buf, ABS_X(XOff));
       PixelToMeasurementUnit(y_buf, ABS_Y(YOff));
-      sprintf(buf, "[%s,%s]", x_buf, y_buf);
+      if (simpleMotionInDrawWin && curChoice == NOTHING && topSel != NULL &&
+            VerboseMeasureTooltip()) {
+         char w_buf[80], h_buf[80];
+         char lx_buf[80], ty_buf[80], rx_buf[80], by_buf[80];
+
+         PixelToMeasurementUnit(w_buf, selObjRbX-selObjLtX);
+         PixelToMeasurementUnit(h_buf, selObjRbY-selObjLtY);
+         PixelToMeasurementUnit(lx_buf, selObjLtX);
+         PixelToMeasurementUnit(rx_buf, selObjRbX);
+         PixelToMeasurementUnit(ty_buf, selObjLtY);
+         PixelToMeasurementUnit(by_buf, selObjRbY);
+         sprintf(buf,
+         "[%s,%s]\nsel_lx=%s sel_rx=%s\nsel_ty=%s sel_by=%s\nsel_w=%s sel_h=%s",
+               x_buf, y_buf, lx_buf, rx_buf, ty_buf, by_buf, w_buf, h_buf);
+      } else {
+         sprintf(buf, "[%s,%s]", x_buf, y_buf);
+      }
       if (showMeasurementInTooltip) {
          SetMeasureTooltip(buf);
       } else {
          XDrawString(mainDisplay, hRuleWindow, revDefaultGC,
                8, 2+defaultFontAsc, buf, strlen(buf));
       }
-   } else if (showMeasurement && showMeasurementInTooltip &&
-         measureTooltipVerbose) {
+   } else if (VerboseMeasureTooltip()) {
       switch (curChoice) {
       case NOTHING:
       case DRAWPOLY:
       case DRAWPOLYGON:
       case VERTEXMODE:
          DoIntervalMeasureTooltip(frozenXOff, frozenYOff, XOff, YOff,
-               (frozenXOff+XOff)>>1, (frozenYOff+YOff)>>1);
+               (frozenXOff+XOff)>>1, (frozenYOff+YOff)>>1, gpszFrozenDeltaStr);
          break;
       }
    }
@@ -626,6 +646,11 @@ void FreezeMarkRulerText()
    freezeMarkRulerText = TRUE;
    frozenXOff = oldXOff;
    frozenYOff = oldYOff;
+   UtilFree(gpszFrozenDeltaStr);
+   if (gpszOldDeltaStr != NULL) {
+      gpszFrozenDeltaStr = UtilStrDup(gpszOldDeltaStr);
+      if (gpszFrozenDeltaStr == NULL) FailAllocMessage();
+   }
 }
 
 void UnFreezeMarkRulerText()
@@ -636,6 +661,12 @@ void UnFreezeMarkRulerText()
 
 static int oldLtX, oldLtY, oldRbX, oldRbY, oldMdX, oldMdY;
 
+int VerboseMeasureTooltip()
+{
+   return (showMeasurement && showMeasurementInTooltip &&
+         measureTooltipVerbose);
+}
+
 static
 void DoIntervalRulers()
 {
@@ -677,8 +708,9 @@ void DoIntervalRulers()
       XDrawLine(mainDisplay, drawWindow, revDefaultGC, 0, oldRbY,
             ZOOMED_SIZE(drawWinW), oldRbY);
    }
-   if (showMeasurement && showMeasurementInTooltip && measureTooltipVerbose) {
-      DoIntervalMeasureTooltip(oldLtX, oldLtY, oldRbX, oldRbY, oldMdX, oldMdY);
+   if (VerboseMeasureTooltip()) {
+      DoIntervalMeasureTooltip(oldLtX, oldLtY, oldRbX, oldRbY, oldMdX, oldMdY,
+            gpszOldDeltaStr);
    }
 }
 
@@ -697,17 +729,23 @@ void BeginIntervalRulers(ltx, lty, rbx, rby)
    oldRbX = rbx; oldRbY = rby;
    oldMdX = (oldLtX+oldRbX)>>1;
    oldMdY = (oldLtY+oldRbY)>>1;
+   gpszOldDeltaStr = NULL;
    if (showMeasurement) FreezeMarkRulerText();
    DoIntervalRulers();
 }
 
-void DrawIntervalRulers(ltx, lty, rbx, rby)
+void DrawIntervalRulers(ltx, lty, rbx, rby, delta_str)
    int ltx, lty, rbx, rby;
+   char *delta_str;
 {
    DoIntervalRulers();
    oldLtX = ltx; oldLtY = lty;
    oldRbX = rbx; oldRbY = rby;
    oldMdX = (oldLtX+oldRbX)>>1; oldMdY = (oldLtY+oldRbY)>>1;
+   if (delta_str != NULL) {
+      gpszOldDeltaStr = UtilStrDup(delta_str);
+      if (gpszOldDeltaStr == NULL) FailAllocMessage();
+   }
    DoIntervalRulers();
    if (showMeasurement) UnFreezeMarkRulerText();
 }
@@ -718,6 +756,8 @@ void EndIntervalRulers(x, y)
    DoIntervalRulers();
    oldXOff = x;
    oldYOff = y;
+   UtilFree(gpszOldDeltaStr);
+   gpszOldDeltaStr = NULL;
    DrawHRuleTick(oldXOff-1);
    DrawVRuleTick(oldYOff-1);
    if (showCrossHair) {
@@ -964,8 +1004,9 @@ void SetMeasureTooltipBBox(msg)
    CalcMeasureTooltipPosition();
 }
 
-void DoIntervalMeasureTooltip(ltx, lty, rbx, rby, mdx, mdy)
+void DoIntervalMeasureTooltip(ltx, lty, rbx, rby, mdx, mdy, delta_str)
    int ltx, lty, rbx, rby, mdx, mdy;
+   char *delta_str;
 {
    char w_buf[80], h_buf[80], buf[256];
    char lx_buf[80], cx_buf[80], rx_buf[80];
@@ -979,8 +1020,14 @@ void DoIntervalMeasureTooltip(ltx, lty, rbx, rby, mdx, mdy)
    PixelToMeasurementUnit(ty_buf, ABS_Y(lty < rby ? lty : rby));
    PixelToMeasurementUnit(my_buf, ABS_Y(mdy));
    PixelToMeasurementUnit(by_buf, ABS_Y(lty > rby ? lty : rby));
-   sprintf(buf, "lx=%s cx=%s rx=%s\nty=%s my=%s by=%s\nw=%s h=%s",
-         lx_buf, cx_buf, rx_buf, ty_buf, my_buf, by_buf, w_buf, h_buf);
+   if (delta_str != NULL) {
+      sprintf(buf, "lx=%s cx=%s rx=%s\nty=%s my=%s by=%s\nw=%s h=%s\n%s",
+            lx_buf, cx_buf, rx_buf, ty_buf, my_buf, by_buf, w_buf, h_buf,
+            delta_str);
+   } else {
+      sprintf(buf, "lx=%s cx=%s rx=%s\nty=%s my=%s by=%s\nw=%s h=%s",
+            lx_buf, cx_buf, rx_buf, ty_buf, my_buf, by_buf, w_buf, h_buf);
+   }
    SetMeasureTooltip(buf);
 }
 
